/**
 * @author Hamadou BA
 * Dépôt GitLab : https://www-apps.univ-lehavre.fr/forge/bh243413/tp6-ps-methode-des-moindres-carrees.git
 * 
 * Classe utilitaire pour charger des données depuis un fichier de ressources.
 * Permet de lire les points de support à partir d'un fichier texte
 * situé dans le dossier resources du projet.
 */

package tp6.ps;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.IOException;
import java.util.ArrayList;

public class DataLoader {
    
    public static double[][] loadDataFromFile(String filename) throws IOException {
        ArrayList<Double> xList = new ArrayList<>();
        ArrayList<Double> yList = new ArrayList<>();
        
        InputStream inputStream = DataLoader.class.getClassLoader().getResourceAsStream(filename);
        if (inputStream == null) {
            throw new IOException("Fichier non trouvé: " + filename);
        }
        
        try (BufferedReader reader = new BufferedReader(new InputStreamReader(inputStream))) {
            String line;
            while ((line = reader.readLine()) != null) {
                line = line.trim();
                if (line.isEmpty() || line.startsWith("#")) continue;
                
                String[] values = line.split("\\s+");
                if (values.length >= 2) {
                    xList.add(Double.parseDouble(values[0]));
                    yList.add(Double.parseDouble(values[1]));
                }
            }
        }
        
        double[] x = new double[xList.size()];
        double[] y = new double[yList.size()];
        
        for (int i = 0; i < xList.size(); i++) {
            x[i] = xList.get(i);
            y[i] = yList.get(i);
        }
        
        return new double[][]{x, y};
    }
}