/**
 * @author Hamadou BA
 * Dépôt GitLab : https://www-apps.univ-lehavre.fr/forge/bh243413/tp6-ps-methode-des-moindres-carrees.git
 * 
 * Classe principale pour l'exécution du programme.
 * Permet à l'utilisateur de spécifier un fichier de données et un degré de polynôme,
 * puis calcule et affiche l'approximation polynomiale par moindres carrés.
 */

package tp6.ps;

import java.io.IOException;
import java.util.Scanner;


public class Main {
    
	
    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);
        
        System.out.print("Entrez le nom du fichier contenant les points de support (ex: donnees.txt): ");
        String filename = scanner.nextLine();
        
        try {
            double[][] data = DataLoader.loadDataFromFile(filename);
            double[] x = data[0];
            double[] y = data[1];
            
            System.out.print("Entrez le degré du polynôme d'approximation: ");
            int degree = scanner.nextInt();
            
            ModPoly poly = new ModPoly(degree);
            poly.identifie(x, y);
            
            System.out.println("Polynôme identifié: " + poly);
            
            String baseFilename = filename;
            if (filename.contains(".")) {
                baseFilename = filename.substring(0, filename.lastIndexOf("."));
            }
            
            String outputFilename = baseFilename + "_deg" + degree;
            
            ChartVisualizer.visualizePolynomial(poly, x, y, outputFilename);
            
        } catch (IOException e) {
            System.err.println("Erreur lors de la lecture du fichier: " + e.getMessage());
            System.exit(1);
        } finally {
            scanner.close();
        }
    }
}